@@ -10,6 +10,6 @@ class IndexAdmin(InstrumentModelAdmin):
         ("Instrument Information", InstrumentModelAdmin.fieldsets[0][1]),
         (
             "Index Information",
-            {"fields": (("net_asset_value_computation_method_path",),)},
+            {"fields": (("net_asset_value_computation_method_path", "order_routing_custodian_adapter"),)},
         ),
     )
