@@ -1,3 +1,5 @@
+from contextlib import suppress
+
 from wbcore.contrib.directory.viewsets.previews import EntryPreviewConfig
 from wbcore.contrib.icons import WBIcon
 from wbcore.metadata.configs import buttons as bt
@@ -17,12 +19,10 @@ class CompanyPreviewConfig(EntryPreviewConfig):
             ["asset_under_management", "invested_assets_under_management_usd"],
             [repeat_field(2, "potential")],
         ]
-        try:
+        with suppress(Exception):
             entry = self.view.get_object()
             if entry.profile_image:
                 fields.insert(0, [repeat_field(2, "profile_image")])
-        except Exception:
-            pass
 
         return create_simple_display(fields)
 
