@@ -18,6 +18,6 @@ class RebalancerFactory(factory.django.DjangoModelFactory):
     portfolio = factory.SubFactory("wbportfolio.factories.portfolios.PortfolioFactory")
     rebalancing_model = factory.SubFactory(RebalancingModelFactory)
     parameters = dict()
-    approve_trade_proposal_automatically = False
+    apply_order_proposal_automatically = False
     frequency = "RRULE:FREQ=MONTHLY;"
     activation_date = None
