@@ -4,9 +4,8 @@ from decimal import Decimal
 
 import factory
 from faker import Faker
-from pandas._libs.tslibs.offsets import BDay
 
-from wbportfolio.models import Trade, TradeProposal
+from wbportfolio.models import Trade
 
 fake = Faker()
 
@@ -26,17 +25,7 @@ class TradeFactory(factory.django.DjangoModelFactory):
     marked_for_deletion = False
     shares = factory.Faker("pydecimal", min_value=10, max_value=1000, right_digits=4)
     price = factory.LazyAttribute(lambda o: random.randint(10, 10000))
-    # trade_proposal = factory.SubFactory("wbportfolio.factories.TradeProposalFactory")
-
-
-class TradeProposalFactory(factory.django.DjangoModelFactory):
-    class Meta:
-        model = TradeProposal
-
-    trade_date = factory.LazyAttribute(lambda o: (fake.date_object() + BDay(1)).date())
-    comment = factory.Faker("paragraph")
-    portfolio = factory.SubFactory("wbportfolio.factories.PortfolioFactory")
-    creator = factory.SubFactory("wbcore.contrib.directory.factories.PersonFactory")
+    # order_proposal = factory.SubFactory("wbportfolio.factories.OrderProposalFactory")
 
 
 class CustomerTradeFactory(TradeFactory):
