@@ -1,7 +1,3 @@
-from contextlib import suppress
-
-import pandas as pd
-import requests
 from django.db.models import Q
 from dynamic_preferences.registries import global_preferences_registry
 from wbfdm.models import Instrument
@@ -11,19 +7,6 @@ def get_timedelta_import_instrument_price():
     return global_preferences_registry.manager()["wbportfolio__timedelta_import_instrument_price"]
 
 
-def process_request(authentication_token: str, endpoint: str | None = None, kwargs={}) -> pd.DataFrame:
-    headers = {"Authorization": authentication_token}
-    r = requests.get(endpoint, params=kwargs, headers=headers)
-    if r.status_code == requests.codes.ok:
-        with suppress(
-            requests.exceptions.JSONDecodeError
-        ):  # we catch any json decode error because the UBS api doesn't seem to respect HTTP status code rule (i.e. returns 200 even though the http content is malformed)
-            r_json = r.json()
-            if r_json.get("status", "") == "SUCCESS":
-                return r_json
-    raise ValueError(f"Issue while processing request: {r.content}")
-
-
 def filter_active_instruments(_date, queryset=None):
     if not queryset:
         queryset = Instrument.objects
