@@ -65,15 +65,15 @@ class TradeImportHandler(ImportExportHandler):
                 try:
                     product = Product.objects.get(id=underlying_instrument.id)
                     data["shares"] = nominal / product.share_price
-                except Product.DoesNotExist:
+                except Product.DoesNotExist as e:
                     raise DeserializationError(
                         "We cannot compute the number of shares from the nominal value as we cannot find the product share price."
-                    )
+                    ) from e
         else:
             raise DeserializationError("We couldn't find a valid underlying instrument this row.")
 
         for field in self.model._meta.get_fields():
-            if not (value := data.get(field.name, None)) is None and isinstance(field, models.DecimalField):
+            if (value := data.get(field.name, None)) is not None and isinstance(field, models.DecimalField):
                 q = (
                     1 / (math.pow(10, 4))
                 )  # we need that convertion mechanism otherwise there is floating point approximation error while casting to decimal and get_instance does not work as expected
@@ -86,7 +86,7 @@ class TradeImportHandler(ImportExportHandler):
             data["transaction_date"] = data["book_date"]
         return self.model.objects.create(**data, import_source=self.import_source)
 
-    def _get_instance(self, data: Dict[str, Any], history: Optional[models.QuerySet] = None, **kwargs) -> models.Model:
+    def _get_instance(self, data: Dict[str, Any], history: Optional[models.QuerySet] = None, **kwargs) -> models.Model:  # noqa: C901
         self.import_source.log += "\nGet Trade Instance."
         if transaction_date := data.get("transaction_date"):
             dates_lookup = {"transaction_date": transaction_date}
