@@ -7,7 +7,7 @@ def parse(import_source):
     if (
         (data_backend := import_source.source.data_backend)
         and (backend_class := data_backend.backend_class)
-        and (default_mapping := getattr(backend_class, "DEFAULT_MAPPING"))
+        and (default_mapping := backend_class.DEFAULT_MAPPING)
     ):
         df = pd.read_json(import_source.file, orient="records")
         if not df.empty:
