@@ -13,8 +13,8 @@ logger = logging.getLogger("importers.parsers.jpmorgan.index")
 def file_name_parse(file_name):
     dates = re.findall("([0-9]{8})", file_name)
 
-    assert len(dates) == 1, "Not exactly 1 date found in the filename"
-
+    if len(dates) != 1:
+        raise ValueError("Not exactly 1 date found in the filename")
     return {"valuation_date": datetime.datetime.strptime(dates[0], "%Y%m%d").date()}
 
 
