@@ -14,8 +14,8 @@ logger = logging.getLogger("importers.parsers.jp_morgan.strategy")
 def file_name_parse(file_name):
     dates = re.findall("([0-9]{8})", file_name)
 
-    assert len(dates) == 1, "Not exactly 1 date found in the filename"
-
+    if len(dates) != 1:
+        raise ValueError("Not exactly 1 date found in the filename")
     return {"valuation_date": datetime.datetime.strptime(dates[0], "%Y%m%d").date()}
 
 
@@ -23,7 +23,7 @@ def parse(import_source):
     data = list()
     prices = list()
     df_dict = pd.read_excel(BytesIO(import_source.file.read()), engine="openpyxl", sheet_name=None)
-    for sheet_name, df in df_dict.items():
+    for df in df_dict.values():
         xx, yy = np.where(df == "Ticker")
         if len(xx) == 1 and len(yy) == 1:
             df_info = df.iloc[: xx[0] - 1, :].transpose()
