@@ -7,7 +7,8 @@ import xlrd
 def file_name_parse(file_name):
     isin = re.findall("([A-Z]{2}[A-Z0-9]{9}[0-9]{1})", file_name)
 
-    assert len(isin) == 1, "Not exactly 1 isin found in the filename"
+    if len(isin) != 1:
+        raise ValueError("Not exactly 1 isin found in the filename")
 
     return {"isin": isin[0]}
 
