@@ -24,7 +24,9 @@ def convert_string_to_number(string):
         return 0.0
 
 
-def parse_date(date, formats=[]):
+def parse_date(date, formats: list | None = None):
+    if formats is None:
+        formats = []
     if isinstance(date, int) or isinstance(date, float):
         return xldate_as_datetime(int(date), 0).date()
     if isinstance(date, str):
