@@ -5,6 +5,7 @@ from decimal import Decimal, InvalidOperation
 from typing import TYPE_CHECKING
 
 from django.contrib import admin
+from django.core.exceptions import ObjectDoesNotExist
 from django.db import models
 from django.db.models import (
     Case,
@@ -408,7 +409,7 @@ class AssetPosition(ImportMixin, models.Model):
     analytical_objects = AnalyticalAssetPositionManager()
     unannotated_objects = models.Manager()
 
-    def pre_save(
+    def pre_save(  # noqa: C901
         self, create_underlying_quote_price_if_missing: bool = False, infer_underlying_quote_price: bool = True
     ):
         if not self.asset_valuation_date:
@@ -429,7 +430,7 @@ class AssetPosition(ImportMixin, models.Model):
         ):
             try:
                 self.underlying_quote = self.underlying_instrument.children.get(is_primary=True)
-            except:
+            except ObjectDoesNotExist:
                 self.underlying_quote = self.underlying_instrument
 
         if not getattr(self, "currency", None):
