@@ -834,7 +834,7 @@ class LiquidityStressMixin:
 
     """ The main function for the liquidity stress tests """
 
-    def liquidity_stress_test(
+    def liquidity_stress_test(  # noqa: C901
         self,
         report_date: Optional[date] = None,
         weights_date: Optional[date] = None,
