@@ -7,6 +7,7 @@ from typing import Any, TypeVar
 
 from celery import shared_task
 from django.core.exceptions import ValidationError
+from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import DatabaseError, models
 from django.db.models import (
     F,
@@ -96,12 +97,22 @@ class OrderProposal(CloneMixin, RiskCheckMixin, WBModel):
     min_order_value = models.IntegerField(
         default=0, verbose_name="Minimum Order Value", help_text="Minimum Order Value in the Portfolio currency"
     )
+    min_weighting = models.DecimalField(
+        max_digits=9,
+        decimal_places=Order.ORDER_WEIGHTING_PRECISION,
+        default=Decimal(0),
+        help_text="The minimum weight allowed for this order proposal ",
+        verbose_name="Minimum Weight",
+        validators=[MinValueValidator(Decimal("0")), MaxValueValidator(Decimal("1"))],
+    )
+
     total_cash_weight = models.DecimalField(
         default=Decimal("0"),
         decimal_places=4,
         max_digits=5,
         verbose_name="Total Cash Weight",
         help_text="The desired percentage for the cash component. The remaining percentage (100% minus this value) will be allocated to total target weighting. Default is 0%.",
+        validators=[MinValueValidator(Decimal("0")), MaxValueValidator(Decimal("1"))],
     )
     total_effective_portfolio_contribution = models.DecimalField(
         default=Decimal("1"),
@@ -136,6 +147,13 @@ class OrderProposal(CloneMixin, RiskCheckMixin, WBModel):
         ]
 
     def save(self, *args, **kwargs):
+        # if the order proposal is created, we default these fields with the portfolio default value for automatic value assignement
+        if not self.id and not self.min_order_value:
+            self.min_order_value = self.portfolio.default_order_proposal_min_order_value
+        if not self.id and not self.min_weighting:
+            self.min_weighting = self.portfolio.default_order_proposal_min_weighting
+        if not self.id and not self.total_cash_weight:
+            self.total_cash_weight = self.portfolio.default_order_proposal_total_cash_weight
         # if a order proposal is created before the existing earliest order proposal, we automatically shift the linked instruments inception date to allow automatic NAV computation since the new inception date
         if not self.portfolio.order_proposals.filter(trade_date__lt=self.trade_date).exists():
             # we need to set the inception date as the first order proposal trade date (and thus, the first position date). We expect a NAV at 100 then
@@ -509,10 +527,11 @@ class OrderProposal(CloneMixin, RiskCheckMixin, WBModel):
             total_target_weight=self.total_expected_target_weight,
         )
         leftovers_orders = self.orders.all()
+        portfolio_value = self.portfolio_total_asset_value
         for underlying_instrument_id, order_dto in service.trades_batch.trades_map.items():
             with suppress(Order.DoesNotExist):
                 order = self.orders.get(underlying_instrument_id=underlying_instrument_id)
-                order.weighting = round(order_dto.delta_weight, Order.ORDER_WEIGHTING_PRECISION)
+                order.set_weighting(round(order_dto.delta_weight, Order.ORDER_WEIGHTING_PRECISION), portfolio_value)
                 order.save()
                 leftovers_orders = leftovers_orders.exclude(id=order.id)
         leftovers_orders.delete()
@@ -521,11 +540,12 @@ class OrderProposal(CloneMixin, RiskCheckMixin, WBModel):
     def fix_quantization(self):
         if self.orders.exists():
             orders = self.get_orders()
+            portfolio_value = self.portfolio_total_asset_value
             t_weight = orders.aggregate(models.Sum("target_weight"))["target_weight__sum"] or Decimal("0.0")
             # we handle quantization error due to the decimal max digits. In that case, we take the biggest order (highest weight) and we remove the quantization error
             if quantize_error := (t_weight - self.total_expected_target_weight):
                 biggest_order = orders.exclude(underlying_instrument__is_cash=True).latest("target_weight")
-                biggest_order.weighting -= quantize_error
+                biggest_order.set_weighting(biggest_order.weighting - quantize_error, portfolio_value)
                 biggest_order.save()
 
     def _get_default_target_portfolio(self, use_desired_target_weight: bool = False, **kwargs) -> PortfolioDTO:
@@ -576,6 +596,7 @@ class OrderProposal(CloneMixin, RiskCheckMixin, WBModel):
                 orders = service.trades_batch.trades_map.values()
 
             objs = []
+            portfolio_value = self.portfolio_total_asset_value
             for order_dto in orders:
                 instrument = Instrument.objects.get(id=order_dto.underlying_instrument)
                 currency_fx_rate = instrument.currency.convert(
@@ -586,7 +607,6 @@ class OrderProposal(CloneMixin, RiskCheckMixin, WBModel):
                 daily_return = order_dto.daily_return
                 try:
                     order = self.orders.get(underlying_instrument=instrument)
-                    order.weighting = weighting
                     order.currency_fx_rate = currency_fx_rate
                     order.daily_return = daily_return
                 except Order.DoesNotExist:
@@ -598,11 +618,12 @@ class OrderProposal(CloneMixin, RiskCheckMixin, WBModel):
                         daily_return=daily_return,
                         currency_fx_rate=currency_fx_rate,
                     )
+                order.pre_save()
+                order.set_weighting(weighting, portfolio_value)
                 order.desired_target_weight = order_dto.target_weight
                 order.order_type = Order.get_type(
                     weighting, round(order_dto.previous_weight, 8), round(order_dto.target_weight, 8)
                 )
-                order.pre_save()
                 # # if we cannot automatically find a price, we consider the stock is invalid and we sell it
                 # if not order.price and order.weighting > 0:
                 #     order.price = Decimal("0.0")
@@ -620,7 +641,7 @@ class OrderProposal(CloneMixin, RiskCheckMixin, WBModel):
                     "price",
                     "price_gross",
                     "desired_target_weight",
-                    # "shares"
+                    "shares",
                 ],
                 unique_fields=["order_proposal", "underlying_instrument"],
                 update_conflicts=True,
@@ -657,7 +678,7 @@ class OrderProposal(CloneMixin, RiskCheckMixin, WBModel):
                 except (ValidationError, DatabaseError) as e:
                     self.status = OrderProposal.Status.FAILED
                     if not silent_exception:
-                        raise ValidationError(e)
+                        raise ValidationError(e) from e
                     return
             logger.info("Submitting order proposal ...")
             self.submit()
@@ -772,7 +793,6 @@ class OrderProposal(CloneMixin, RiskCheckMixin, WBModel):
         price_fx_portfolio = quote_price * underlying_quote.currency.convert(
             self.trade_date, self.portfolio.currency, exact_lookup=False
         )
-
         # If the price is valid, calculate and return the estimated shares
         if price_fx_portfolio:
             return trade_total_value_fx_portfolio / price_fx_portfolio
@@ -870,6 +890,7 @@ class OrderProposal(CloneMixin, RiskCheckMixin, WBModel):
             order_warnings = order.submit(
                 by=by, description=description, portfolio_total_asset_value=self.portfolio_total_asset_value, **kwargs
             )
+
             if order_warnings:
                 orders_validation_warnings.extend(order_warnings)
             orders.append(order)
@@ -1175,7 +1196,7 @@ class OrderProposal(CloneMixin, RiskCheckMixin, WBModel):
         return warning
 
     def can_cancelexecution(self):
-        if not self.execution_status in [ExecutionStatus.PENDING, ExecutionStatus.IN_DRAFT]:
+        if self.execution_status not in [ExecutionStatus.PENDING, ExecutionStatus.IN_DRAFT]:
             return {"execution_status": "Execution can only be cancelled if it is not already executed"}
 
     def update_execution_status(self):
