@@ -71,6 +71,22 @@ class TransactionMixin(models.Model):
         ),
         db_persist=True,
     )
+    price_fx_portfolio = models.GeneratedField(
+        expression=models.F("currency_fx_rate") * models.F("price"),
+        output_field=models.DecimalField(
+            max_digits=20,
+            decimal_places=4,
+        ),
+        db_persist=True,
+    )
+    price_gross_fx_portfolio = models.GeneratedField(
+        expression=models.F("currency_fx_rate") * models.F("price_gross"),
+        output_field=models.DecimalField(
+            max_digits=20,
+            decimal_places=4,
+        ),
+        db_persist=True,
+    )
     total_value_fx_portfolio = models.GeneratedField(
         expression=models.F("currency_fx_rate") * models.F("price") * models.F("shares"),
         output_field=models.DecimalField(
@@ -100,14 +116,10 @@ class TransactionMixin(models.Model):
             self.price_gross = self.price
         elif self.price_gross is not None and self.price is None:
             self.price = self.price_gross
-
-    def save(self, *args, **kwargs):
-        self.pre_save()
         if self.currency_fx_rate is None:
             self.currency_fx_rate = self.underlying_instrument.currency.convert(
                 self.value_date, self.portfolio.currency, exact_lookup=True
             )
-        super().save(*args, **kwargs)
 
     class Meta:
         abstract = True
