@@ -269,7 +269,7 @@ class TradeBatch:
 
     def convert_to_portfolio(self, use_effective: bool = False, *extra_positions):
         positions = []
-        for instrument, trade in self.trades_map.items():
+        for trade in self.trades_map.values():
             positions.append(
                 Position(
                     underlying_instrument=trade.underlying_instrument,
