@@ -1,5 +1,3 @@
-from wbfdm.models import InstrumentPrice
-
 from wbportfolio.pms.typing import Portfolio
 from wbportfolio.rebalancing.base import AbstractRebalancingModel
 from wbportfolio.rebalancing.decorators import register
@@ -9,6 +7,11 @@ from wbportfolio.rebalancing.decorators import register
 class ModelPortfolioRebalancing(AbstractRebalancingModel):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self.value_date = (
+            self.trade_date
+            if self.model_portfolio.assets.filter(date=self.trade_date).exists()
+            else self.last_effective_date
+        )
 
     @property
     def model_portfolio_rel(self):
@@ -20,19 +23,15 @@ class ModelPortfolioRebalancing(AbstractRebalancingModel):
 
     @property
     def assets(self):
-        return self.model_portfolio.get_positions(self.last_effective_date) if self.model_portfolio else []
+        return self.model_portfolio.get_positions(self.value_date) if self.model_portfolio else []
 
     def is_valid(self) -> bool:
-        instruments = list(map(lambda o: o.underlying_quote, self.assets))
-        return (
-            len(self.assets) > 0
-            and InstrumentPrice.objects.filter(date=self.trade_date, instrument__in=instruments).exists()
-        )
+        return len(self.assets) > 0
 
     def get_target_portfolio(self) -> Portfolio:
         positions = []
         for asset in self.assets:
-            asset.date = self.trade_date
-            asset.asset_valuation_date = self.trade_date
+            asset.date = self.value_date
+            asset.asset_valuation_date = self.value_date
             positions.append(asset._build_dto())
         return Portfolio(positions=tuple(positions))
