@@ -1,4 +1,3 @@
-from .trade_proposals import TradeProposalModelSerializer, ReadOnlyTradeProposalModelSerializer
 from .claim import (
     ClaimAccountSerializer,
     ClaimAPIModelSerializer,
@@ -12,8 +11,5 @@ from .dividends import DividendModelSerializer, DividendRepresentationSerializer
 from .fees import FeesModelSerializer, FeesRepresentationSerializer
 from .trades import (
     TradeModelSerializer,
-    TradeProposalRepresentationSerializer,
-    TradeRepresentationSerializer,
-    TradeTradeProposalModelSerializer,
-    ReadOnlyTradeTradeProposalModelSerializer,
+    TradeRepresentationSerializer
 )
