@@ -500,17 +500,25 @@ class TestOrderProposal:
         instrument.exchange.save()
         assert order_proposal.get_round_lot_size(Decimal("66"), instrument) == Decimal("66")
 
-    def test_submit_round_lot_size(self, order_proposal, order_factory, instrument_factory):
+    @patch.object(Portfolio, "get_total_asset_value")
+    def test_submit_round_lot_size(self, mock_fct, order_proposal, instrument_price_factory, order_factory):
+        initial_shares = Decimal("70")
+        price = instrument_price_factory.create(date=order_proposal.trade_date)
+        net_value = round(price.net_value, 4)
+        portfolio_value = initial_shares * net_value
+        mock_fct.return_value = portfolio_value
+
         order_proposal.portfolio.only_weighting = False
         order_proposal.portfolio.save()
-        instrument = instrument_factory.create()
+        instrument = price.instrument
         instrument.round_lot_size = 100
         instrument.save()
         trade = order_factory.create(
-            underlying_instrument=instrument,
-            shares=70,
+            shares=initial_shares,
             order_proposal=order_proposal,
             weighting=Decimal("1.0"),
+            underlying_instrument=price.instrument,
+            price=net_value,
         )
         warnings = order_proposal.submit()
         order_proposal.save()
@@ -520,18 +528,31 @@ class TestOrderProposal:
         trade.refresh_from_db()
         assert trade.shares == 100  # we expect the share to be transformed from 70 to 100 (lot size of 100)
 
-    def test_submit_round_fractional_shares(self, order_proposal, order_factory):
+    @patch.object(Portfolio, "get_total_asset_value")
+    def test_submit_round_fractional_shares(self, mock_fct, instrument_price_factory, order_proposal, order_factory):
+        initial_shares = Decimal("5.6")
+        price = instrument_price_factory.create(date=order_proposal.trade_date)
+        net_value = round(price.net_value, 4)
+        portfolio_value = initial_shares * net_value
+        mock_fct.return_value = portfolio_value
+
         order_proposal.portfolio.only_weighting = False
         order_proposal.portfolio.save()
         trade = order_factory.create(
-            shares=5.6,
+            shares=Decimal("5.6"),
             order_proposal=order_proposal,
             weighting=Decimal("1.0"),
+            underlying_instrument=price.instrument,
+            price=net_value,
         )
         order_proposal.submit()
         order_proposal.save()
         trade.refresh_from_db()
         assert trade.shares == 6  # we expect the fractional share to be rounded
+        assert trade.weighting == round((trade.shares * net_value) / portfolio_value, 8)
+        assert trade.weighting == round(
+            Decimal("1") + ((Decimal("6") - initial_shares) * net_value) / portfolio_value, 8
+        )  # we expect the weighting to be updated accrodingly
 
     def test_ex_post(
         self, instrument_factory, asset_position_factory, instrument_price_factory, order_proposal_factory, portfolio
@@ -695,6 +716,37 @@ class TestOrderProposal:
         assert order.shares == Decimal(0)
         assert order.weighting == Decimal(0)
 
+    def test_order_submit_bellow_minimum_weighting(self, order_factory, order_proposal):
+        o1 = order_factory.create(order_proposal=order_proposal, price=Decimal(1), weighting=Decimal("0.8"))
+        o2 = order_factory.create(order_proposal=order_proposal, price=Decimal(1), weighting=Decimal("0.2"))
+        order_proposal.submit()
+        order_proposal.save()
+
+        o1.refresh_from_db()
+        o2.refresh_from_db()
+        assert o1.weighting == Decimal("0.8")
+        assert o2.weighting == Decimal("0.2")
+
+        order_proposal.min_weighting = Decimal("0.21")
+        order_proposal.backtodraft()
+        order_proposal.submit()
+        order_proposal.save()
+
+        o1.refresh_from_db()
+        o2.refresh_from_db()
+        assert o1.weighting == Decimal("0.8")
+        assert o2.weighting == Decimal("0")
+
+        order_proposal.approve()
+        order_proposal.apply()
+        order_proposal.save()
+        assert order_proposal.portfolio.assets.get(
+            date=order_proposal.trade_date, underlying_quote=o1.underlying_instrument
+        ).weighting == Decimal("0.8")
+        assert order_proposal.portfolio.assets.get(
+            date=order_proposal.trade_date, underlying_quote=order_proposal.cash_component
+        ).weighting == Decimal("0.2")
+
     def test_reset_order_use_desired_target_weight(self, order_proposal, order_factory):
         order1 = order_factory.create(
             order_proposal=order_proposal, weighting=Decimal("0.5"), desired_target_weight=Decimal("0.7")
