@@ -924,13 +924,13 @@ class TestPortfolioModel(PortfolioTestMixin):
 
         analytic_portfolio = portfolio.get_analytic_portfolio(weekday)
         assert analytic_portfolio.weights.tolist() == [float(a1.weighting), float(a2.weighting)]
-        expected_X = pd.DataFrame(
+        expected_x = pd.DataFrame(
             [[float(p11.net_value / p10.net_value - Decimal(1)), float(p21.net_value / p20.net_value - Decimal(1))]],
             columns=[i1.id, i2.id],
             index=[(weekday + BDay(1)).date()],
         )
-        expected_X.index = pd.to_datetime(expected_X.index)
-        pd.testing.assert_frame_equal(analytic_portfolio.X, expected_X, check_names=False, check_freq=False)
+        expected_x.index = pd.to_datetime(expected_x.index)
+        pd.testing.assert_frame_equal(analytic_portfolio.X, expected_x, check_names=False, check_freq=False)
 
     def test_get_total_asset_value(self, weekday, portfolio, asset_position_factory):
         a1 = asset_position_factory.create(date=weekday, portfolio=portfolio)
@@ -1010,7 +1010,7 @@ class TestPortfolioModel(PortfolioTestMixin):
         assert len(res) == 1
         assert a.date == weekday
         assert a.underlying_quote == instrument
-        assert a.underlying_quote_price == None
+        assert a.underlying_quote_price is None
         assert a.initial_price == p.net_value
         assert a.weighting == pytest.approx(weights[instrument.id], abs=Decimal(10e-6))
         assert a.currency_fx_rate_portfolio_to_usd == fx_portfolio
@@ -1053,7 +1053,7 @@ class TestPortfolioModel(PortfolioTestMixin):
         assert next(gen)[0] == middle_date, "Drifting weight with a non automatic rebalancer stops the iteration"
         try:
             next(gen)
-            assert False, "the next iteration should stop and return the rebalancing"
+            raise AssertionError("the next iteration should stop and return the rebalancing")
         except StopIteration as e:
             rebalancing_order_proposal = e.value
             assert rebalancing_order_proposal.trade_date == rebalancing_date
