@@ -9,7 +9,7 @@ for key, value in default_config.items():
             and x.__name__
             not in [
                 "AggregatedAssetPositionLiquidityPandasView",
-                "TradeTradeProposalModelViewSet",
+                "OrderOrderProposalModelViewSet",
                 "PortfolioSwingPricing",
                 "PortfolioCashTarget",
                 "PortfolioSwingPricingModelViewSet",
@@ -19,6 +19,8 @@ for key, value in default_config.items():
                 "AccountReconciliationLine",
                 "TopDownPortfolioCompositionPandasAPIView",
                 "CompositionModelPortfolioPandasView",
+                "DistributionChartViewSet",
+                "DistributionTableViewSet",
                 # "ClaimModelViewSet",
                 # "ClaimModelSerializer",
             ],
