@@ -101,7 +101,9 @@ class AbstractDistributionMixin(UserPortfolioRequestPermissionMixin):
             columns = {}
             level_representations = self.classification_group.get_levels_representation()
             for key, label in zip(
-                reversed(self.classification_group.get_fields_names(sep="_")), reversed(level_representations[1:])
+                reversed(self.classification_group.get_fields_names(sep="_")),
+                reversed(level_representations[1:]),
+                strict=False,
             ):
                 columns[key] = label
             columns["label"] = "Classification"
@@ -158,6 +160,7 @@ class AbstractDistributionMixin(UserPortfolioRequestPermissionMixin):
         return df.reset_index(names="id")
 
     def manipulate_dataframe(self, df):
+        df["id"] = df["id"].fillna(-1)
         if self.group_by == AssetPositionGroupBy.INDUSTRY:
             if not PortfolioRole.is_analyst(self.request.user.profile, portfolio=self.portfolio):
                 df["equity"] = ""
@@ -169,8 +172,8 @@ class AbstractDistributionMixin(UserPortfolioRequestPermissionMixin):
                 dict(Classification.objects.filter(id__in=df["classification"].dropna()).values_list("id", "name"))
             )
         elif self.group_by == AssetPositionGroupBy.CASH:
-            df.loc[df["id"] == True, "label"] = "Cash"
-            df.loc[df["id"] == False, "label"] = "Non-Cash"
+            df.loc[df["id"], "label"] = "Cash"
+            df.loc[~df["id"], "label"] = "Non-Cash"
         elif self.group_by == AssetPositionGroupBy.COUNTRY:
             df["label"] = df["id"].map(dict(Geography.objects.filter(id__in=df["id"]).values_list("id", "name")))
         elif self.group_by == AssetPositionGroupBy.CURRENCY:
@@ -180,6 +183,7 @@ class AbstractDistributionMixin(UserPortfolioRequestPermissionMixin):
             df["label"] = df["id"].map(
                 dict(InstrumentType.objects.filter(id__in=df["id"]).values_list("id", "short_name"))
             )
+        df.loc[df["id"] == -1, "label"] = "N/A"
         df.sort_values(by="weighting", ascending=False, inplace=True)
         return df
 
@@ -307,7 +311,7 @@ class ContributorPortfolioChartView(UserPortfolioRequestPermissionMixin, viewset
 
             text_forex = df_forex.contribution_forex.apply(lambda x: f"{x:,.2%}")
             text_equity = contribution_equity.apply(lambda x: f"{x:,.2%}")
-            setattr(self, "nb_rows", df.shape[0])
+            self.nb_rows = df.shape[0]
             fig.add_trace(
                 go.Bar(
                     y=df.instrument_id,
