@@ -17,12 +17,7 @@ from .fees import (
     FeesModelViewSet,
     FeesProductModelViewSet,
 )
-from .rebalancing import RebalancingModelRepresentationViewSet, RebalancerRepresentationViewSet, RebalancerModelViewSet
-from .trade_proposals import (
-    TradeProposalModelViewSet,
-    TradeProposalPortfolioModelViewSet,
-    TradeProposalRepresentationViewSet,
-)
+
 from .trades import (
     CustodianDistributionInstrumentChartViewSet,
     CustomerDistributionInstrumentChartViewSet,
@@ -32,5 +27,4 @@ from .trades import (
     TradeModelViewSet,
     TradePortfolioModelViewSet,
     TradeRepresentationViewSet,
-    TradeTradeProposalModelViewSet,
 )
